#!/usr/bin/python2.5
# -*- coding: utf-8 -*-

from pylab import *
plot([1,2,4])
title( unicode('Dvelopps et fabriqus', 'latin-1') )
xlabel( unicode("ractivit nous permettent d'tre slectionns et adopts", 'latin-1') )
ylabel( unicode('Andr\xc3\xa9 was here!', 'utf-8') )
text( 0.5, 2.5, unicode('Institut fr Festkrperphysik', 'latin-1'), rotation=45)
text( 1, 1.5, u'AVA (check kerning)')  

savefig('test.svg')
show()
